hook_states_from_stack

Function hook_states_from_stack 

pub fn hook_states_from_stack(
    config_layer_stack: Option<&ConfigLayerStack>,
) -> HashMap<String, HookStateToml>
Build effective hook state from config layers that are allowed to override user preferences.

This intentionally reads only user and session flag layers, including disabled layers, to match the skills config behavior. Project, managed, and plugin layers can discover hooks, but they do not get to write user hook state.