pub fn plugin_hook_declarations(
hook_sources: &[PluginHookSource],
) -> Vec<PluginHookDeclaration>Expand description
Return the hook handlers declared by plugin bundles without projecting live runtime state.
pub fn plugin_hook_declarations(
hook_sources: &[PluginHookSource],
) -> Vec<PluginHookDeclaration>Return the hook handlers declared by plugin bundles without projecting live runtime state.